import { calendar_v3 } from "googleapis";
import { OAuth2Client, JWT, Compute, UserRefreshClient } from "google-auth-library";
import moment from "moment-timezone";
/** Slot deciding strategies */
export declare type Strategy = "linear" | "heavy-firsts" | "heavy-lasts" | "heavy-centers" | "heavy-mornings" | "heavy-afternoons" | "heavy-evenings" | "heavy-mondays" | "heavy-tuesdays" | "heavy-wednesdays" | "heavy-fridays" | "heavy-saturday" | "heavy-sundays";
/**
 * Get a random element from this array, strategy-weighted
 */
export declare const weightedItemFromArray: (params: GetEventsParams & GetSlotsParams, arr: Slot[], strategies: Strategy[]) => Slot;
export interface GetEventsParams {
    user?: {
        accessToken: string;
        refreshToken: string;
    };
    from: moment.MomentInput;
    to: moment.MomentInput;
    calendar?: calendar_v3.Calendar;
    calendarId?: string;
    auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
}
export interface GetSlotsParams {
    log?: boolean;
    slotDuration?: number;
    slots?: number;
    padding?: number;
    url?: string;
    strategies?: Strategy[];
    weight?: number;
    days?: number[];
    daily?: {
        timezone: string;
        from?: [number, number?, number?];
        to?: [number, number?, number?];
    };
    slotFilter?: (slot: Slot) => boolean;
    logger?: (...args: any[]) => void;
}
export interface Slot {
    start: Date;
    end: Date;
}
/**
 * Find a user's events from a single calendar
 * Defaults to their primary calendar
 */
export declare const getEventsFromSingleCalendar: ({ user, from, to, calendar, calendarId, auth, }: GetEventsParams) => Promise<calendar_v3.Schema$Event[]>;
/**
 * Get a list of user's events from all calendars
 */
export declare const getEventsFromAllCalendars: (params: Pick<GetEventsParams, "user" | "auth" | "from" | "to" | "calendar">) => Promise<calendar_v3.Schema$Event[]>;
/**
 * Get calendar events from a webcal ICS URL
 */
export declare const getEventsFromWebcal: (url: string) => Promise<{
    start: {
        dateTime: string;
    };
    end: {
        dateTime: string;
    };
}[]>;
/**
 * List all free slots for a user
 */
export declare const getSlots: (params: GetEventsParams & GetSlotsParams) => Promise<Slot[]>;
